@@ -136,7 +136,7 @@ def __list_files(dir_name):
         if (len(files) > 0):
             for file in files:
                 r.append(os.path.join(subdir, file))
-    print(r)
+    #print(r)
     return r
 
 
@@ -151,9 +151,9 @@ def __upload_one_file(job_id, type, object_name):
     # request a s3 presigned URL
     object_name_encoded = path_encoder.quote(object_name, safe="") # by default / is recognized as safe
     url = f"{API_GW}/s3url/{job_id}/{type}/{object_name_encoded}"
-    print(f"getting {url}")
+    #print(f"getting {url}")
     response = requests.request("GET", url)
-    print(f"response {response}")
+    #print(f"response {response}")
     response_body = json.loads(response.text)
 
 
@@ -161,7 +161,7 @@ def __upload_one_file(job_id, type, object_name):
         files = {'file': (object_name, f)}
         http_response = requests.post(response_body['url'], data=response_body['fields'], files=files)
     # If successful, returns HTTP status code 204
-    print(f'File upload HTTP status code: {http_response.status_code}')
+    #print(f'File upload HTTP status code: {http_response.status_code}')
 
 
 
@@ -181,6 +181,6 @@ if __name__ == "__main__":
     #getFloderFiles("test")
     #print(files)
     make_tar("yolov5")
-    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"4"}})
+    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
     #make_tar("train.py")
     #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
\ No newline at end of file
